package com.zanxiang.sdk.domain.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.zanxiang.common.enums.ExpireTimeEnum;
import com.zanxiang.common.utils.DateUtils;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.ToString;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * @author : lingfeng
 * @time : 2022-06-06
 * @description : 玩家客户端登录token表
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@ToString
@TableName("h_user_token")
public class UserToken implements Serializable {

    private static final long serialVersionUID = -6515396685604515968L;

    /**
     * id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 玩家id
     */
    private Long userId;

    /**
     * 过期时间
     */
    private Long expireTime;

    /**
     * token
     */
    private String token;

    /**
     * 设备类型;mobile,android,iphone,ipad,web,pc,mac,wxapp
     */
    private String deviceType;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 构造方法
     *
     * @param userId     : 用户id
     * @param token      : token签名
     * @param deviceType : 设备类型
     */
    public UserToken(Long userId, String token, String deviceType) {
        this.userId = userId;
        this.token = token;
        this.deviceType = deviceType;
        this.createTime = LocalDateTime.now();
        this.updateTime = this.createTime;
        this.expireTime = DateUtils.localDateTimeToSecond(this.createTime) + ExpireTimeEnum.ONE_WEEK.getTime();
    }

    /**
     * 更新用户token
     *
     * @param token : 新的token
     */
    public void updateToken(String token) {
        this.token = token;
        this.updateTime = LocalDateTime.now();
        this.expireTime = DateUtils.localDateTimeToSecond(this.updateTime) + ExpireTimeEnum.ONE_WEEK.getTime();
    }
}